@@ -3,7 +3,7 @@ Logging facilities.
 """
 
 import logging
-from version import __title__
+from pkginfo import __title__
 
 #: The logging object.
 log = logging.getLogger(__title__)
